@@ -6,6 +6,7 @@ import time
 from dataclasses import dataclass
 import statistics
 from collections import defaultdict
+
 if TYPE_CHECKING:
     from .interface import RequestResult
 
@@ -20,6 +21,7 @@ class ProgressBarStyle(Enum):
     PIPES = ("┃", "┆", "⚡")  # 管道样式
     STARS = ("★", "☆", "⚡")  # 星星样式
 
+
 @dataclass
 class ProgressBarConfig:
     bar_length: int = 30
@@ -30,8 +32,14 @@ class ProgressBarConfig:
     style: ProgressBarStyle = ProgressBarStyle.BLANK
     use_colors: bool = True
 
+
 class ProgressTracker:
-    def __init__(self, total_requests: int, concurrency=1, config: Optional[ProgressBarConfig] = None):
+    def __init__(
+        self,
+        total_requests: int,
+        concurrency=1,
+        config: Optional[ProgressBarConfig] = None,
+    ):
         self.console = Console()
 
         # 统计信息
@@ -54,28 +62,28 @@ class ProgressTracker:
 
         # ANSI颜色代码
         self.colors = {
-            'green': '\033[92m',
-            'yellow': '\033[93m',
-            'red': '\033[91m',
-            'blue': '\033[94m',
-            'purple': '\033[95m',
-            'cyan': '\033[96m',
-            'reset': '\033[0m',
+            "green": "\033[92m",
+            "yellow": "\033[93m",
+            "red": "\033[91m",
+            "blue": "\033[94m",
+            "purple": "\033[95m",
+            "cyan": "\033[96m",
+            "reset": "\033[0m",
         }
 
     def _format_time(self, seconds: float) -> str:
         """格式化时间显示"""
         if seconds > 3600:
-            return f'{seconds/3600:.1f}h'
+            return f"{seconds / 3600:.1f}h"
         if seconds > 60:
-            return f'{seconds/60:.1f}m'
-        return f'{seconds:.1f}s'
+            return f"{seconds / 60:.1f}m"
+        return f"{seconds:.1f}s"
 
     @staticmethod
     def _format_speed(speed: float) -> str:
         """格式化速度显示"""
         # if speed >= 1:
-        return f'{speed:.1f} req/s'
+        return f"{speed:.1f} req/s"
         # return f'{speed*1000:.0f} req/ms'
 
     def _get_colored_text(self, text: str, color: str) -> str:
@@ -88,7 +96,12 @@ class ProgressTracker:
         """计算最近的请求速度"""
         if len(self.recent_latencies) < 2:
             return 0
-        return len(self.recent_latencies) / sum(self.recent_latencies) * self.concurrency
+
+        total_latency = sum(self.recent_latencies)
+        if total_latency <= 0:
+            return 0
+
+        return len(self.recent_latencies) / total_latency * self.concurrency
 
     def update(self, result: "RequestResult") -> None:
         """
@@ -109,7 +122,11 @@ class ProgressTracker:
             self.success_count += 1
         else:
             self.error_count += 1
-            error_type = result.data.get('error', 'unknown')
+            # 安全地获取错误类型，处理 result.data 为 None 的情况
+            if result.data and isinstance(result.data, dict):
+                error_type = result.data.get("error", "unknown")
+            else:
+                error_type = "unknown"
             self.errors[error_type] = self.errors.get(error_type, 0) + 1
 
         current_time = time.time()
@@ -120,14 +137,17 @@ class ProgressTracker:
         speed = self._calculate_speed()
         avg_latency = statistics.mean(self.latencies) if self.latencies else 0
         remaining_requests = self.total_requests - self.completed_requests
-        estimated_remaining_time = avg_latency * remaining_requests/self.concurrency if avg_latency > 0 else 0
+        estimated_remaining_time = (
+            avg_latency * remaining_requests / self.concurrency
+            if avg_latency > 0
+            else 0
+        )
 
         # 创建进度条
         style = self.config.style.value
         filled_length = int(self.config.bar_length * progress)
-        bar = (
-                style[0] * filled_length +
-                style[1] * (self.config.bar_length - filled_length)
+        bar = style[0] * filled_length + style[1] * (
+            self.config.bar_length - filled_length
         )
 
         # 构建输出组件
@@ -136,18 +156,20 @@ class ProgressTracker:
         # 进度条和百分比
         progress_text = f"[{self._get_colored_text(bar, 'blue')}]"
         if self.config.show_percentage:
-            progress_text += f" {self._get_colored_text(f'{progress*100:.1f}%', 'green')}"
+            progress_text += (
+                f" {self._get_colored_text(f'{progress * 100:.1f}%', 'green')}"
+            )
         components.append(progress_text)
 
         # 请求计数
         if self.config.show_counts:
             counts = f"({self.completed_requests}/{self.total_requests})"
-            components.append(self._get_colored_text(counts, 'yellow'))
+            components.append(self._get_colored_text(counts, "yellow"))
 
         # 速度信息
         if self.config.show_speed:
             speed_text = f"{style[2]} {self._format_speed(speed)}"
-            components.append(self._get_colored_text(speed_text, 'cyan'))
+            components.append(self._get_colored_text(speed_text, "cyan"))
 
         # 时间统计
         if self.config.show_time_stats:
@@ -156,10 +178,32 @@ class ProgressTracker:
                 f"total: {self._format_time(total_time)} "
                 f"eta: {self._format_time(estimated_remaining_time)}"
             )
-            components.append(self._get_colored_text(time_stats, 'purple'))
+            components.append(self._get_colored_text(time_stats, "purple"))
 
-        # 打印进度
-        print('\r' + ' '.join(components), end='', flush=True)
+        # 打印进度 - 修复Windows编码问题
+        try:
+            print("\r" + " ".join(components), end="", flush=True)
+        except UnicodeEncodeError:
+            # Windows GBK编码兼容处理
+            safe_components = []
+            for comp in components:
+                # 替换有问题的Unicode字符
+                safe_comp = comp.replace("⚡", "*").replace("█", "#").replace("─", "-")
+                safe_comp = (
+                    safe_comp.replace("▉", "|").replace("▰", "=").replace("▱", "-")
+                )
+                safe_comp = (
+                    safe_comp.replace("▣", "[").replace("▢", "]").replace("━", "=")
+                )
+                safe_comp = (
+                    safe_comp.replace("┃", "|")
+                    .replace("┆", ":")
+                    .replace("★", "*")
+                    .replace("☆", "+")
+                )
+                safe_comp = safe_comp.replace("⣿", "#").replace("⣀", ".")
+                safe_components.append(safe_comp)
+            print("\r" + " ".join(safe_components), end="", flush=True)
 
     def summary(self, show_p999=False, print_to_console=True) -> str:
         """打印请求汇总信息"""
@@ -184,47 +228,54 @@ class ProgressTracker:
         p99_or_p999_str = p999_str if show_p999 else p99_str
 
         summary = f"""
-## 请求统计
-> **总体情况**
-> - 总请求数: {self.total_requests}
-> - 成功请求数: {self.success_count}
-> - 失败请求数: {self.error_count}
-> - 成功率: {(self.success_count / self.total_requests * 100):.2f}%
+                                   请求统计                                    
 
-> **性能指标**
-> - 平均延迟: {avg_latency:.2f} 秒
-> - P50 延迟: {p50:.2f} 秒
-> - P95 延迟: {p95:.2f} 秒
-{p99_or_p999_str}
-> - 吞吐量: {throughput:.2f} 请求/秒
-> - 总运行时间: {total_time:.2f} 秒
+| 总体情况                                                                   
+|  - 总请求数: {self.total_requests}                                                             
+|  - 成功请求数: {self.success_count}                                                           
+|  - 失败请求数: {self.error_count}                                                           
+|  - 成功率: {(self.success_count / self.total_requests * 100):.2f}%                                                         
+
+| 性能指标                                                                   
+|  - 平均延迟: {avg_latency:.2f} 秒                                                       
+|  - P50 延迟: {p50:.2f} 秒                                                       
+|  - P95 延迟: {p95:.2f} 秒                                                       
+|  - P99 延迟: {p99:.2f} 秒                                                       
+|  - 吞吐量: {throughput:.2f} 请求/秒                                                
+|  - 总运行时间: {total_time:.2f} 秒                                               
 
 """
         # 如果有错误，添加错误统计
         if self.errors:
-            summary += "> **错误分布**\n"
+            summary += "| 错误分布                                                                   \n"
             for error_type, count in self.errors.items():
                 percentage = count / self.error_count * 100
-                summary += f"> - {error_type}: {count} ({percentage:.1f}%)\n"
+                summary += f"|  - {error_type}: {count} ({percentage:.1f}%)                            \n"
 
-        summary += "---"
+        summary += "-" * 76
         if print_to_console:
             print()  # 打印空行
-            self.console.print(Markdown(summary))
+            try:
+                # 尝试使用Rich输出，如果失败则使用普通print
+                self.console.print(summary)
+            except UnicodeEncodeError:
+                # 在Windows GBK环境下，如果出现编码错误，使用普通print
+                print(summary)
         return summary
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     from sparrow.async_api.interface import RequestResult
-    config = ProgressBarConfig(
-    )
-    tracker = ProgressTracker(100,1,  config)
+
+    config = ProgressBarConfig()
+    tracker = ProgressTracker(100, 1, config)
     for i in range(100):
         time.sleep(0.1)
         tracker.update(
             result=RequestResult(
                 request_id=i,
                 data=None,
-                status='success',
+                status="success",
                 latency=0.1,
             )
         )
